'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _acorn = require('acorn');

var _walk = require('acorn/dist/walk');

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _neatContract = require('neat-contract');

var _neatContract2 = _interopRequireDefault(_neatContract);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var parse = function parse(input) {
  return (0, _acorn.parse)(input, { sourceType: 'module', allowHashBang: true });
};

// es2015+
var importValue = _ramda2.default.path(['source', 'value']);

// CommonJS
var isRequire = _ramda2.default.pathEq(['callee', 'name'], 'require');
var isLiteral = _ramda2.default.pipe(_ramda2.default.prop('arguments'), _ramda2.default.head, _ramda2.default.propEq('type', 'Literal'));
var isLiteralRequire = _ramda2.default.both(isRequire, isLiteral);
var requireValue = _ramda2.default.pipe(_ramda2.default.prop('arguments'), _ramda2.default.head, _ramda2.default.prop('value'));

var deps = function deps(ast) {
  var list = [];
  var addToList = function addToList(item) {
    list = list.concat(item);
  };
  (0, _walk.simple)(ast, {
    ImportDeclaration: _ramda2.default.pipe(importValue, addToList),
    CallExpression: _ramda2.default.when(isLiteralRequire, _ramda2.default.pipe(requireValue, addToList))
  });
  return list;
};

// esDepsFromString -> String -> Array[String]
function esDepsFromString(input) {
  return _ramda2.default.pipe((0, _neatContract2.default)('input', String), parse, deps)(input);
}

exports.default = esDepsFromString;
module.exports = exports['default'];
